package sgc.portal.base.service;

import sgc.portal.base.exception.UnsupportedGirdStatusException;
import sgc.portal.base.model.ComData;
import sgc.portal.base.model.EquimentSearch;
import sgc.portal.base.model.NewEmpNoUsePopup;
import sgc.portal.base.persistence.ComPopupMapper;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.base.websquare.GridRowStatus;
import sgc.portal.com.com.model.CommDtl;
import sgc.portal.com.com.model.Menu;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.HashMap;
import java.util.List;

/**
 * The type Com popup service.
 *
 * @author mir(khjang @ sgc.co.kr)
 * @version 1.0.0
 * @since 2020. 8. 2.
 */
@Transactional
@Service
public class ComPopupService {

    private static final Logger LOGGER = LoggerFactory.getLogger(ComPopupService.class);

    @Autowired
    private ComPopupMapper comPopupMapper;

    /**
     * Select comm pop list.
     *
     * @param commdtls the commdtls
     * @return the list
     */
//공통내역코드 정보 조회
    public List<EasyHashMap<String, Object>> selectCommPop(CommDtl commdtls) {
        return comPopupMapper.selectCommPop(commdtls);
    }

    /**
     * Select menu pop list.
     *
     * @param mn the mn
     * @return the list
     */
    public List<EasyHashMap<String, Object>> selectMenuPop(Menu mn) {
        return comPopupMapper.selectMenuPop(mn);
    }



    /**
     * Selectcom dpt all pop list.
     *
     * @param comdata the comdata
     * @return the list
     */
//부서 전체 조회  kkh추가(2019.12.19)
    public List<EasyHashMap<String, Object>> selectcomDptAllPop(ComData comdata) {
        return comPopupMapper.selectcomDptAllPop(comdata);
    }

    /**
     * Select emp pop list.
     *
     * @param comdata the comdata
     * @return the list
     */
//사원 팝업 조회  kkh추가(2020.01.22)
    public List<EasyHashMap<String, Object>> selectEmpPopLst(ComData comdata) {
    	return comPopupMapper.selectEmpPopLst(comdata);
    }

    /**
     * Selectcom site pop list.
     *
     * @param comdata the comdata
     * @return the list
     */
//현장 조회 추가(2023.03.16)
    public List<EasyHashMap<String, Object>> selectcomSitePop(ComData comdata) {
    	return comPopupMapper.selectcomSitePop(comdata);
    }

    /**
     * Selectcom site pop list.
     *
     * @param comdata the comdata
     * @return the list
     */
//차량정보 조회 추가(2023.05.24)
    public List<EasyHashMap<String, Object>> selectCarInfoLst(ComData comdata) {
    	return comPopupMapper.selectCarInfoLst(comdata);
    }
    
}
