package sgc.portal.base.persistence;

import sgc.portal.base.util.EasyHashMap;
import sgc.portal.base.model.ComData;
import sgc.portal.base.model.EquimentSearch;
import sgc.portal.base.model.NewEmpNoUsePopup;
import sgc.portal.com.com.model.CommDtl;
import sgc.portal.com.com.model.Menu;
import org.apache.ibatis.annotations.Mapper;

import java.util.HashMap;
import java.util.List;

/**
 * 프로그램 목록 매퍼  DAO
 *
 * @author mir(khjang@sgc.co.kr)
 * @version 1.0.0
 * @since  2020. 8. 2.
 */


@Mapper
public interface ComPopupMapper {
    //공통내역코드 정보 조회
    List<EasyHashMap<String, Object>> selectCommPop(CommDtl commdtls);

    //사원 팝업 조회
    List<EasyHashMap<String, Object>> selectEmpPopLst(ComData comdata);

    //메뉴 정보 조회
    List<EasyHashMap<String, Object>> selectMenuPop(Menu mn);

    //부서 전체 조회  kkh추가(2019.12.19)
    List<EasyHashMap<String, Object>> selectcomDptAllPop(ComData comdata);

    //현장 조회 추가(2023.03.16)
    List<EasyHashMap<String, Object>> selectcomSitePop(ComData comdata);

    //차량정보 조회 추가(2023.05.24)
    List<EasyHashMap<String, Object>> selectCarInfoLst(ComData comdata);
}
